SwipeCards<T> class

A widget that displays a stack of swipeable cards.

The cards are built using cardBuilder, and can be swiped in four directions (left, right, up, down). Callbacks are triggered for each swipe direction if provided.

Example:

SwipeCards<String>(
  items: ['A', 'B', 'C'],
  cardBuilder: (item) => Card(child: Text(item)),
  onSwipeLeft: (item) => print('Swiped left: $item'),
)
Inheritance

Constructors

SwipeCards({required List<T> items, required Widget cardBuilder(T item), bool loop = false, dynamic onSwipeLeft(T item)?, dynamic onSwipeRight(T item)?, dynamic onSwipeUp(T item)?, dynamic onSwipeDown(T item)?, SwipeCardsController<T>? controller, Key? key})
Creates a SwipeCards widget.
const

Properties

cardBuilder Widget Function(T item)
A builder function to create a widget for each item.
final
controller SwipeCardsController<T>?
An optional controller to trigger swipe actions program
final
hashCode int
The hash code for this object.
no setterinherited
items List<T>
The list of items that will be shown as swipeable cards.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loop bool
Whether the cards should loop when reaching the end of items.
final
onSwipeDown → dynamic Function(T item)?
Callback when a card is swiped down.
final
onSwipeLeft → dynamic Function(T item)?
Callback when a card is swiped left.
final
onSwipeRight → dynamic Function(T item)?
Callback when a card is swiped right.
final
onSwipeUp → dynamic Function(T item)?
Callback when a card is swiped up.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _SwipeCardsState<T>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited