SwipeCardsController<T> class
A controller that provides callbacks for swipe directions.
Use this to handle swipe gestures (left, right, up, down) in your swipe card widget.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- swipeDown ↔ void Function()?
-
Called when a card is swiped down.
getter/setter pair
- swipeLeft ↔ void Function()?
-
Called when a card is swiped left.
getter/setter pair
- swipeRight ↔ void Function()?
-
Called when a card is swiped right.
getter/setter pair
- swipeUp ↔ void Function()?
-
Called when a card is swiped up.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited